# WRFdownscalingML

Framework for downscaling WRF output statistics using machine learning algorithm.

## Getting Started
#### Dependencies
You need Python 3.7 or later to use **WRFdownscalingML:**. You can find it at [python.org](https://www.python.org/).
You also need pandas, numpy, matplotlib and netCDF4 packages, which is available from [PyPI](https://pypi.org). If you have pip, just run:
```
pip install pandas
pip install numpy
pip install matplotlib
pip install netCDF4
```
#### Installation
Clone this repo to your local machine using:
```
git clone https://github.com/rjsampa/WRFdownscalingML
```

Or with pip install:
```
pip install WRFdownscalingML
```

## Features
- File structure for PyPI packages
- Setup with package informations
- License 	
